/*
 * Tirititran es un juego de naves en 2D ambientado en Cádiz
 * Copyright (C) 2004  Javier Pérez Pacheco
 *
 * Este juego tienen licencia Creative Commons y se permite
 * su modificacion y utilizacion libremente siempre y cuando se
 * cite al autor original y se comparta con la misma licencia.
 * No se permite su uso comercial.
 * 
 * Para mas informacion visite la web:
 * http://creativecommons.org/licenses/by-nc-sa/2.0/es/
 *
 * PROGRAMADOR
 * Javier Pérez Pacheco
 * Cadiz (Spain)
 * javi.pacheco@terra.es
 *
 * GRAFISMO Y 3D
 * Jesus Carrasco
 * Cadiz (Spain)
 * carrasco.carrasco@gmail.com
 *
 * MUSICA Y GRAFISMO
 * Shano Lores
 * Cadiz (Spain)
 * shano@mail.ono.es
 *
 */
 
#ifndef JUEGO_H_
#define JUEGO_H_

#include <SDL.h>
#include "defines.h"
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

class Juego {
	
private:
	int vidas;
	int nivel;
	int puntos;
	int ciclos;
	int gameover;
	bool hacerClip;// esta variale comprueba si hay que hacer actualizar la barra (0) o si no (1)
	bool poderActivo; // hay algun poder activo
	int nPoderes; // numero de poderes del jugador
	int estadoBarraPoder; // estado de la barra de poder. Con 3 suma un nuevo poder
	int poderSeleccionado;
	int tipoDisparo; // 0 , 1 o 2
	int tiempoPoder;
	bool enFinal; // si se encuentra en el final de fase
	int nContinues;
	int zonaSobrepasada; // 0 - principio de fase, 1 - mitad, 2 - final
	int cicloConversacionAleatoria;
	int conversacionParaAbrirEnFase; // numero de la conversacion a abrir. 1 o 2
	bool mapaParado;

public:
	Juego();
	void setMapaParado (bool m) { mapaParado = m; }
	bool getMapaParado () { return mapaParado; }
	void setCicloConversarionAleatoria ();
	int getCicloConversarionAleatoria () { return cicloConversacionAleatoria; }
	void setConversacionParaAbrirEnFase ();
	int getConversacionParaAbrirEnFase () { return conversacionParaAbrirEnFase; }
	void setZonaSobrepasada (int zs) { zonaSobrepasada = zs; }
	int getZonaSobrepasada () { return zonaSobrepasada; }
	void establecerContinue () { nContinues = NUMEROCONTINUES; }
	void setContinue (int n) { nContinues = n; }
	void removeContinue () { nContinues--; }
	int getContinue () { return nContinues; }
	void setEnFinal(bool f) { enFinal = f; }
	bool getEnFinal () { return enFinal; }
	void setVidas(int v) { hacerClip = 0; vidas = v; }
	void addVidas() { hacerClip = 0;  vidas++; }
	void removeVidas() { vidas--; }
	int getVidas () { return vidas; }
	void setHacerClip(int hc) { hacerClip = hc; }
	int getHacerClip() { return hacerClip; }
	void setPoderActivo(int pa) { poderActivo = pa; }
	bool getPoderActivo() { return poderActivo; }
	void setNivel (int n) { nivel = n; }
	void addNivel () { nivel++; }
	int getNivel () { return nivel; }
	void setTiempoPoder (int tp) { tiempoPoder = tp; }
	void addTiempoPoder () { tiempoPoder++; }
	int getTiempoPoder () { return tiempoPoder; }
	void setPoderSel (int p) { hacerClip = 0;  poderSeleccionado = p; }
	void addPoderSel () { hacerClip = 0;  if ( poderSeleccionado < 4) { poderSeleccionado++; } else { poderSeleccionado = 1; } }
	void removePoderSel () { hacerClip = 0;  if ( poderSeleccionado > 1) { poderSeleccionado--; } else { poderSeleccionado = 4; } }
	int getPoderSel () { return poderSeleccionado; }
	void setPuntos (int p) { hacerClip = 0;  puntos = p; }
	void addPuntos (int p) { hacerClip = 0;  puntos += p; }
	int getPuntos () { return puntos; }
	void setPoderes (int p) { hacerClip = 0; nPoderes = p; }
	void addPoderes () { hacerClip = 0; nPoderes++;  }
	void removePoderes () { hacerClip = 0;  nPoderes--; }
	int getPoderes () { return nPoderes; }
	void setBarraPoder (int p) { hacerClip = 0;  estadoBarraPoder = p; }
	void addBarraPoder () { if (estadoBarraPoder < 4) { hacerClip = 0; estadoBarraPoder++; } }
	int getBarraPoder () { return estadoBarraPoder; }
	void setCiclos (int c) { ciclos = c; }
	void addCiclos () { ciclos++; }
	int getCiclos () { return ciclos; }
	void setTipoDisparo (int td) { tipoDisparo = td; }
	void addTipoDisparo () { if ( tipoDisparo<2 ) tipoDisparo++; }
	int getTipoDisparo () { return tipoDisparo; }
	void setGameOver (int go) { gameover = go; }
	int getGameOver () { return gameover; }
	void iniciar ();
	char* getTituloNombreFase();
	char* getTituloNombreCortoFase();
	char* getTituloNumeroFase();
};


#endif /* JUEGO_H_ */
